pub fn merge_entry_iters<'a, EntIter, Ent, K>(
    entry_iters: impl Iterator<Item = EntIter>
) -> impl 'a + Iterator<Item = Ent>
where EntIter: 'a + Iterator<Item = Ent>, Ent: 'a + Mergeable<K>, K: 'a + Ord,
K-merges and then dedupes the arg iters.

@arg entry_iters: An iterator of iterators of entrysets, where each entryset contains borrowable Ks and is internally sorted by K, from newer entryset to older entryset.